@@ -26,13 +26,13 @@ Copyright 1987 by Digital Equipment Corporation, Maynard, Massachusetts.
 
                         All Rights Reserved
 
-Permission to use, copy, modify, and distribute this software and its 
-documentation for any purpose and without fee is hereby granted, 
+Permission to use, copy, modify, and distribute this software and its
+documentation for any purpose and without fee is hereby granted,
 provided that the above copyright notice appear in all copies and that
-both that copyright notice and this permission notice appear in 
+both that copyright notice and this permission notice appear in
 supporting documentation, and that the name of Digital not be
 used in advertising or publicity pertaining to distribution of the
-software without specific, written prior permission.  
+software without specific, written prior permission.
 
 DIGITAL DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING
 ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL
@@ -82,7 +82,7 @@ SOFTWARE.
 #define EINVAL WSAEINVAL
 #undef EBADF
 #define EBADF WSAENOTSOCK
-/* Windows select does not set errno. Use GetErrno as wrapper for 
+/* Windows select does not set errno. Use GetErrno as wrapper for
    WSAGetLastError */
 #define GetErrno WSAGetLastError
 #else
@@ -121,9 +121,9 @@ struct _OsTimerRec {
     void *arg;
 };
 
-static void DoTimer(OsTimerPtr timer, CARD32 now, volatile OsTimerPtr *prev);
+static void DoTimer(OsTimerPtr timer, CARD32 now, OsTimerPtr *prev);
 static void CheckAllTimers(void);
-static volatile OsTimerPtr timers = NULL;
+static OsTimerPtr timers = NULL;
 
 /*****************
  * WaitForSomething:
@@ -167,7 +167,7 @@ WaitForSomething(int *pClientsReady)
     busfault_check();
 #endif
 
-    /* We need a while loop here to handle 
+    /* We need a while loop here to handle
        crashed connections and the screen saver timeout */
     while (1) {
         /* deal with any blocked jobs */
@@ -263,14 +263,11 @@ WaitForSomething(int *pClientsReady)
                 if ((int) (timers->expires - now) <= 0)
                     expired = 1;
 
-                if (expired) {
-                    OsBlockSignals();
-                    while (timers && (int) (timers->expires - now) <= 0)
-                        DoTimer(timers, now, &timers);
-                    OsReleaseSignals();
+                while (timers && (int) (timers->expires - now) <= 0)
+                    DoTimer(timers, now, &timers);
 
+                if (expired)
                     return 0;
-                }
             }
         }
         else {
@@ -284,14 +281,11 @@ WaitForSomething(int *pClientsReady)
                     if ((int) (timers->expires - now) <= 0)
                         expired = 1;
 
-                    if (expired) {
-                        OsBlockSignals();
-                        while (timers && (int) (timers->expires - now) <= 0)
-                            DoTimer(timers, now, &timers);
-                        OsReleaseSignals();
+                    while (timers && (int) (timers->expires - now) <= 0)
+                        DoTimer(timers, now, &timers);
 
+                    if (expired)
                         return 0;
-                    }
                 }
             }
             if (someReady)
@@ -349,14 +343,14 @@ WaitForSomething(int *pClientsReady)
              *  ready, they are all returned.  This means that an
              *  aggressive client could take over the server.
              *  This was not considered a big problem because
-             *  aggressive clients can hose the server in so many 
+             *  aggressive clients can hose the server in so many
              *  other ways :)
              */
             client_priority = clients[client_index]->priority;
             if (nready == 0 || client_priority > highest_priority) {
                 /*  Either we found the first client, or we found
                  *  a client whose priority is greater than all others
-                 *  that have been found so far.  Either way, we want 
+                 *  that have been found so far.  Either way, we want
                  *  to initialize the list of clients to contain just
                  *  this client.
                  */
@@ -364,7 +358,7 @@ WaitForSomething(int *pClientsReady)
                 highest_priority = client_priority;
                 nready = 1;
             }
-            /*  the following if makes sure that multiple same-priority 
+            /*  the following if makes sure that multiple same-priority
              *  clients get batched together
              */
             else if (client_priority == highest_priority) {
@@ -407,25 +401,24 @@ CheckAllTimers(void)
 }
 
 static void
-DoTimer(OsTimerPtr timer, CARD32 now, volatile OsTimerPtr *prev)
+DoTimer(OsTimerPtr timer, CARD32 now, OsTimerPtr *prev)
 {
     CARD32 newTime;
 
     OsBlockSignals();
     *prev = timer->next;
     timer->next = NULL;
-    OsReleaseSignals();
-
     newTime = (*timer->callback) (timer, now, timer->arg);
     if (newTime)
         TimerSet(timer, 0, newTime, timer->callback, timer->arg);
+    OsReleaseSignals();
 }
 
 OsTimerPtr
 TimerSet(OsTimerPtr timer, int flags, CARD32 millis,
          OsTimerCallback func, void *arg)
 {
-    volatile OsTimerPtr *prev;
+    register OsTimerPtr *prev;
     CARD32 now = GetTimeInMillis();
 
     if (!timer) {
@@ -477,7 +470,7 @@ Bool
 TimerForce(OsTimerPtr timer)
 {
     int rc = FALSE;
-    volatile OsTimerPtr *prev;
+    OsTimerPtr *prev;
 
     OsBlockSignals();
     for (prev = &timers; *prev; prev = &(*prev)->next) {
@@ -494,7 +487,7 @@ TimerForce(OsTimerPtr timer)
 void
 TimerCancel(OsTimerPtr timer)
 {
-    volatile OsTimerPtr *prev;
+    OsTimerPtr *prev;
 
     if (!timer)
         return;
@@ -522,12 +515,8 @@ TimerCheck(void)
 {
     CARD32 now = GetTimeInMillis();
 
-    if (timers && (int) (timers->expires - now) <= 0) {
-        OsBlockSignals();
-        while (timers && (int) (timers->expires - now) <= 0)
-            DoTimer(timers, now, &timers);
-        OsReleaseSignals();
-    }
+    while (timers && (int) (timers->expires - now) <= 0)
+        DoTimer(timers, now, &timers);
 }
 
 void
