@@ -97,7 +97,7 @@ RROutputCreate(ScreenPtr pScreen,
     output->changed = FALSE;
     output->devPrivate = devPrivate;
 
-    if (!AddResource(output->id, RROutputType, (pointer) output))
+    if (!AddResource(output->id, RROutputType, (void *) output))
         return NULL;
 
     pScrPriv->outputs[pScrPriv->numOutputs++] = output;
@@ -337,7 +337,7 @@ RROutputDestroy(RROutputPtr output)
 }
 
 static int
-RROutputDestroyResource(pointer value, XID pid)
+RROutputDestroyResource(void *value, XID pid)
 {
     RROutputPtr output = (RROutputPtr) value;
     ScreenPtr pScreen = output->pScreen;
@@ -487,6 +487,7 @@ ProcRRGetOutputInfo(ClientPtr client)
         swapl(&rep.mmHeight);
         swaps(&rep.nCrtcs);
         swaps(&rep.nModes);
+        swaps(&rep.nPreferred);
         swaps(&rep.nClones);
         swaps(&rep.nameLength);
     }
